==> jc-1.4.0.tar.gz: soot/grimp/internal/GStaticInvokeExpr.h <==
// public class soot.grimp.internal.GStaticInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fdc9ddab507b0298 soot_grimp_internal_GStaticInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStaticInvokeExpr

#include "soot/jimple/internal/AbstractStaticInvokeExpr.h"

#ifndef _JC_soot_grimp_internal_GStaticInvokeExpr_H_
#define _JC_soot_grimp_internal_GStaticInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs	_jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs	_jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$refs	_jc_soot_grimp_internal_GStaticInvokeExpr$refs;
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$nonrefs	_jc_soot_grimp_internal_GStaticInvokeExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$object	_jc_soot_grimp_internal_GStaticInvokeExpr$object;

typedef const struct _jc_soot_grimp_internal_GStaticInvokeExpr$vmethods	_jc_soot_grimp_internal_GStaticInvokeExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GStaticInvokeExpr$vtable	_jc_soot_grimp_internal_GStaticInvokeExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GStaticInvokeExpr$vtype	_jc_soot_grimp_internal_GStaticInvokeExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GStaticInvokeExpr$method$_init$6327f5fb7966d9c6(_jc_env *, struct _jc_soot_grimp_internal_GStaticInvokeExpr$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GStaticInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GStaticInvokeExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GStaticInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GStaticInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GStaticInvokeExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GStaticInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_grimp_internal_GStaticInvokeExpr$vmethods	soot_grimp_internal_GStaticInvokeExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GStaticInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GStaticInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GStaticInvokeExpr$refs {
    _jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs	soot_grimp_internal_GStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GStaticInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs	soot_grimp_internal_GStaticInvokeExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GStaticInvokeExpr$object {
	_jc_soot_grimp_internal_GStaticInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GStaticInvokeExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GStaticInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GStaticInvokeExpr$vtype _jc_soot_grimp_internal_GStaticInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GStaticInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GStaticInvokeExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GStaticInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GStaticInvokeExpr.h <==
// public class soot.grimp.internal.GStaticInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fdc9ddab507b0298 soot_grimp_internal_GStaticInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStaticInvokeExpr

#include "soot/jimple/internal/AbstractStaticInvokeExpr.h"

#ifndef _JC_soot_grimp_internal_GStaticInvokeExpr_H_
#define _JC_soot_grimp_internal_GStaticInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs	_jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs	_jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$refs	_jc_soot_grimp_internal_GStaticInvokeExpr$refs;
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$nonrefs	_jc_soot_grimp_internal_GStaticInvokeExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GStaticInvokeExpr$object	_jc_soot_grimp_internal_GStaticInvokeExpr$object;

typedef const struct _jc_soot_grimp_internal_GStaticInvokeExpr$vmethods	_jc_soot_grimp_internal_GStaticInvokeExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GStaticInvokeExpr$vtable	_jc_soot_grimp_internal_GStaticInvokeExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GStaticInvokeExpr$vtype	_jc_soot_grimp_internal_GStaticInvokeExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GStaticInvokeExpr$method$_init$6327f5fb7966d9c6(_jc_env *, struct _jc_soot_grimp_internal_GStaticInvokeExpr$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GStaticInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GStaticInvokeExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GStaticInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GStaticInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GStaticInvokeExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GStaticInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_grimp_internal_GStaticInvokeExpr$vmethods	soot_grimp_internal_GStaticInvokeExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GStaticInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GStaticInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GStaticInvokeExpr$refs {
    _jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs	soot_grimp_internal_GStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GStaticInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs	soot_grimp_internal_GStaticInvokeExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GStaticInvokeExpr$object {
	_jc_soot_grimp_internal_GStaticInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GStaticInvokeExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GStaticInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GStaticInvokeExpr$vtype _jc_soot_grimp_internal_GStaticInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GStaticInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GStaticInvokeExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GStaticInvokeExpr_H_ */
